@@ -19,8 +19,14 @@
 #include <cmath>
 #include <cstdlib>
 #include <iostream>
+
+#ifdef _WIN32
+#include "Windows/unistd.h"
+#include "Windows/getopt.h"
+#else
 #include <unistd.h>
 #include <getopt.h>
+#endif
 
 #include "somoclu.h"
 
@@ -101,7 +107,7 @@ int main(int argc, char** argv)
     MPI_Bcast(&nSomX, 1, MPI_INT, 0, MPI_COMM_WORLD);
     MPI_Bcast(&nSomY, 1, MPI_INT, 0, MPI_COMM_WORLD);
     MPI_Bcast(&kernelType, 1, MPI_INT, 0, MPI_COMM_WORLD);
-    MPI_Bcast(&mapType, 1, MPI_INT, 0, MPI_COMM_WORLD);
+
     char *inFilenameCStr = new char[255];
     if (rank == 0) {
         strcpy(inFilenameCStr,inFilename.c_str());
@@ -109,6 +115,13 @@ int main(int argc, char** argv)
     MPI_Bcast(inFilenameCStr, 255, MPI_CHAR, 0, MPI_COMM_WORLD);
     inFilename = inFilenameCStr;
 
+    char *mapTypeCStr = new char[255];
+    if (rank == 0) {
+        strcpy(mapTypeCStr,mapType.c_str());
+    }
+    MPI_Bcast(mapTypeCStr, 255, MPI_CHAR, 0, MPI_COMM_WORLD);
+    mapType = mapTypeCStr;
+
     double profile_time = MPI_Wtime();
 #endif
 
@@ -226,7 +239,7 @@ void printUsage() {
          "     -r NUMBER             Start radius (default: half of the map in direction min(x,y))\n" \
          "     -R NUMBER             End radius (default: 1)\n" \
          "     -T STRATEGY           Learning rate cooling strategy: linear or exponential (default: linear)\n" \
-         "     -l NUMBER             Starting learning rate (default: 1.0)\n" \
+         "     -l NUMBER             Starting learning rate (default: 0.1)\n" \
          "     -L NUMBER             Finishing learning rate (default: 0.01)\n" \
          "     -s NUMBER             Save interim files (default: 0):\n" \
          "                              0: Do not save interim files\n" \
